==> postman_dio-1.0.2.tar.gz: lib/src/core/postman_dio_logger.dart <==
import 'package:dio/dio.dart';
import 'package:postman_dio/helpers.dart';
import 'package:postman_dio/models.dart';

class PostmanDioLogger extends Interceptor {
  PostmanDioLogger({
    this.logPrint = print,
    this.enablePrint = false,
    this.maxMilliseconds,
  });

  // ignore: use_setters_to_change_properties
  static void changeNameCollection(String name) {
    postmanCollection.info!.name = name;
  }

  static PostmanCollection postmanCollection = PostmanCollection(
    info: InfoCollection(
        name: 'PostmanDioLogger ${DateTime.now().toUtc()}', schema: 'https://schema.getpostman.com/json/collection/v2.1.0/collection.json'),
    item: [],
  );

  final stopwatch = Stopwatch();
  final bool enablePrint;

  /// Log if the request is executed more than maxMilliseconds ms, if 'null' log all request
  final int? maxMilliseconds;

  /// Log printer; defaults logPrint log to console.
  /// In flutter, you'd better use debugPrint.
  /// you can also write log in a file.
  void Function(Object object) logPrint;

  // you can override this for change your log value
  Future<String?>? getPrintValue(ItemPostmanRequest? request) => getPrintJson(request);

  ItemPostmanRequest? newRequest;

  /// JSON collection for import by the postman or another client
  static Future<String> export() async {
    return postmanCollection.toJson();
  }

  @override
  Future<void> onRequest(RequestOptions options, RequestInterceptorHandler? handler) async {
    try {
      stopwatch.start();
      newRequest = ItemPostmanRequest(
        name: options.safeUri?.toString(),
        request: await RequestPostman.fromRequest(options),
      );
      postmanCollection.item!.add(newRequest);
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(options);
  }

  @override
  Future<void> onError(DioError err, ErrorInterceptorHandler? handler) async {
    try {
      _checkTime();
      newRequest ??= ItemPostmanRequest(
        name: err.response?.requestOptions.path == null ? null : err.response?.requestOptions.uri.toString(),
        request: await RequestPostman.fromRequest(err.response?.requestOptions),
      );
      newRequest!
        ..name = '[${stopwatch.elapsedMilliseconds}ms] ${newRequest!.name}'
        ..request = newRequest!.request?.copyWith(
          description: err.toString(),
        );
      await _log();
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(err);
  }

  @override
  Future<void> onResponse(Response response, ResponseInterceptorHandler? handler) async {
    try {
      _checkTime();
      newRequest!
        ..name = '[${stopwatch.elapsedMilliseconds}ms] ${newRequest!.name}'
        ..request = newRequest!.request?.copyWith(
          description: response.toString(),
        )
        ..response = <ResponsePostman>[
          ResponsePostman(
            name: response.requestOptions.safeUri?.toString(),
            code: response.statusCode,
            status: response.statusMessage,
            originalRequest: await RequestPostman.fromRequest(response.requestOptions),
            body: await TransformerJson.encode(response.data),
            header: response.headers.map.keys
                .map((key) => HeaderPostman(
                      key: key,
                      value: response.headers[key]?.toString(),
                    ))
                .toList(),
          ),
        ];
      await _log();
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(response);
  }

  void _checkTime() {
    stopwatch.stop();
    if (maxMilliseconds != null) {
      if (stopwatch.elapsedMilliseconds < maxMilliseconds!) {
        postmanCollection.item!.remove(newRequest);
      }
    }
  }

  Future<void> _log() async {
    if (enablePrint) {
      if (maxMilliseconds != null) {
        if (stopwatch.elapsedMilliseconds < maxMilliseconds!) {
          return;
        }
      }
      logPrint(await getPrintValue(newRequest) ?? '');
    }
  }

  Future<String?>? getPrintJson(ItemPostmanRequest? request) async {
    return request?.toJson();
  }

  Future<String> getPrintSimple(ItemPostmanRequest? request) async {
    return '${request?.request?.method}:${request?.response?.firstOrDefault?.code} ${request?.request?.url?.raw}';
  }
}

==> postman_dio-1.0.3.tar.gz: lib/src/core/postman_dio_logger.dart <==
import 'package:dio/dio.dart';
import 'package:postman_dio/helpers.dart';
import 'package:postman_dio/models.dart';

class PostmanDioLogger extends Interceptor {
  PostmanDioLogger({
    this.logPrint = print,
    this.enablePrint = false,
    this.maxMilliseconds,
    this.options = const PostmanDioLoggerOptions(),
  });

  // ignore: use_setters_to_change_properties
  static void changeNameCollection(String name) {
    postmanCollection.info!.name = name;
  }

  static PostmanCollection postmanCollection = PostmanCollection(
    info: InfoCollection(
        name: 'PostmanDioLogger ${DateTime.now().toUtc()}', schema: 'https://schema.getpostman.com/json/collection/v2.1.0/collection.json'),
    item: [],
  );

  final stopwatch = Stopwatch();
  final bool enablePrint;

  /// Log if the request is executed more than maxMilliseconds ms, if 'null' log all request
  final int? maxMilliseconds;

  /// Log printer; defaults logPrint log to console.
  /// In flutter, you'd better use debugPrint.
  /// you can also write log in a file.
  void Function(Object object) logPrint;

  /// Additional logger options.
  final PostmanDioLoggerOptions options;

  // you can override this for change your log value
  Future<String?>? getPrintValue(ItemPostmanRequest? request) => getPrintJson(request);

  ItemPostmanRequest? newRequest;

  /// JSON collection for import by the postman or another client
  static Future<String> export() async {
    return postmanCollection.toJson();
  }

  @override
  Future<void> onRequest(RequestOptions options, RequestInterceptorHandler? handler) async {
    try {
      stopwatch.start();
      newRequest = ItemPostmanRequest(
        name: options.safeUri?.toString(),
        request: await RequestPostman.fromRequest(options),
      );
      postmanCollection.item!.add(newRequest);
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(options);
  }

  @override
  Future<void> onError(DioError err, ErrorInterceptorHandler? handler) async {
    try {
      _checkTime();
      newRequest ??= ItemPostmanRequest(
        name: err.response?.requestOptions.path == null ? null : err.response?.requestOptions.uri.toString(),
        request: await RequestPostman.fromRequest(err.response?.requestOptions),
      );
      newRequest!
        ..name = '[${stopwatch.elapsedMilliseconds}ms] ${newRequest!.name}'
        ..request = newRequest!.request?.copyWith(
          description: err.toString(),
        )
        ..response = <ResponsePostman>[
          ResponsePostman(
            name: newRequest!.name,
            code: err.response?.statusCode,
            status: err.response?.statusMessage,
            originalRequest: await RequestPostman.fromRequest(err.response?.requestOptions),
            body: err.response?.data == null ? await TransformerJson.encode(err.response?.data) : err.message,
            header: err.response?.headers.map.keys
                .map((key) => HeaderPostman(
                      key: key,
                      value: err.response?.headers[key]?.toString(),
                    ))
                .toList(),
          ),
        ];
      await _log(newRequest!);
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(err);
  }

  @override
  Future<void> onResponse(Response response, ResponseInterceptorHandler? handler) async {
    try {
      _checkTime();
      newRequest!
        ..name = '[${stopwatch.elapsedMilliseconds}ms] ${newRequest!.name}'
        ..request = newRequest!.request?.copyWith(
          description: response.toString(),
        )
        ..response = <ResponsePostman>[
          ResponsePostman(
            name: response.requestOptions.safeUri?.toString(),
            code: response.statusCode,
            status: response.statusMessage,
            originalRequest: await RequestPostman.fromRequest(response.requestOptions),
            body: await TransformerJson.encode(response.data),
            header: response.headers.map.keys
                .map((key) => HeaderPostman(
                      key: key,
                      value: response.headers[key]?.toString(),
                    ))
                .toList(),
          ),
        ];
      await _log(newRequest!);
    } catch (error, stackTrace) {
      l.log('$error', name: 'PostmanDioLogger', error: error, stackTrace: stackTrace);
    }
    return handler?.next(response);
  }

  void _checkTime() {
    stopwatch.stop();
    if (maxMilliseconds != null) {
      if (stopwatch.elapsedMilliseconds < maxMilliseconds!) {
        postmanCollection.item!.remove(newRequest);
      }
    }
  }

  Future<void> _log(ItemPostmanRequest request) async {
    final requestSucceed = request.response?.firstOrDefault?.code == 200;
    if (enablePrint && ((options.printOnSuccess && requestSucceed) || (options.printOnError && !requestSucceed))) {
      if (maxMilliseconds != null) {
        if (stopwatch.elapsedMilliseconds < maxMilliseconds!) {
          return;
        }
      }
      logPrint(await getPrintValue(request) ?? '');
    }
  }

  Future<String?>? getPrintJson(ItemPostmanRequest? request) async {
    return request?.toJson();
  }

  Future<String> getPrintSimple(ItemPostmanRequest? request) async {
    return '${request?.request?.method}:${request?.response?.firstOrDefault?.code} ${request?.request?.url?.raw}';
  }
}

/// Additional configuration options for PostmanDioLogger.
class PostmanDioLoggerOptions {
  const PostmanDioLoggerOptions({
    this.printOnSuccess = true,
    this.printOnError = true,
  });

  /// if true, [PostmanDioLogger.logPrint] will be called on request success.
  final bool printOnSuccess;

  /// if true, [PostmanDioLogger.logPrint] will be called on request error.
  final bool printOnError;
}
